/*
 * tkGeometry.h --
 *
 *	Declarations for things used by Tk geometry managers.
 *
 * Author: Pekka Nikander <pnr@ajk.tele.fi>
 *
 * Copyright 1992 Telecom Finland
 *
 * Permission to use, copy, modify, and distribute this
 * software and its documentation for any purpose and without
 * fee is hereby granted, provided that the above copyright
 * notice appear in all copies.  Telecom Finland
 * makes no representations about the suitability of this
 * software for any purpose.  It is provided "as is" without
 * express or implied warranty.
 *
 * Created: Sun Mar  8 17:49:25 1992
 * Last modified: Wed Mar 11 20:51:00 1992 pnr
 */

#ifndef _TK_GEOM_MANAGER
#define _TK_GEOM_MANAGER

#ifndef _XLIB_H_
#include <X11/Xlib.h>
#endif
#ifndef _XUTIL_H
#include <X11/Xutil.h>
#endif
#ifndef _TK
#include "tk.h"
#endif
#ifndef _TCL
#include "tcl.h"
#endif
#ifndef _TCLHASH
#include "tclhash.h"
#endif

/*
 * The experimental geometry managers keep the following strutures for
 * each manager.  
 * WARNING: the declaration below must be kept consistent with the
 * TkWindow structure in tkInt.h.  If you change one, be sure to
 * change the other!!
 */

typedef struct TkGeomManager {
    Display *display;		/* Display containing window. */
    TkDisplay *dispPtr;		/* Tk's information about display
				 * for window. */
    int screenNum;		/* Index of screen for window, among all
				 * those for dispPtr. */
    struct {
	Window dummy1;		/* window */
	void *dummy2;		/* childList  */
    } unused1;

    Tk_Window tkwin;		/* The tkwin associated with.
				 * NOTE! This is the parent window!
				 * (in the window hierarchy sense) */

    struct {
	void *dummy6;		/* nextPtr */
    } unused2;

    TkMainInfo *mainPtr;	/* Information shared by all windows
				 * (and now, by all geometry managers :-)
				 * associated with a particular main
				 * window. */

    char *pathName;		/* Path name of geometry manager
				 * (concatenation of all windown names
				 * between this geometry manager and
				 * its top-level window ancestor).
				 * This is a pointer into an entry in
				 * mainPtr->nameTable or NULL if
				 * mainPtr is NULL. */
    Tk_Uid nameUid;		/* Name of the geometry manager within its
				   parent */
    Tk_Uid classUid;		/* Class of the geometry manager. */

    struct {
	XWindowChanges dummy1;	/* changed */
	unsigned int dummy2;	/* dirtyChanges */
	XSetWindowAttributes dummy3; /* atts */
	unsigned long dummy4;	/* dirtyAtts */
    } unused3;

    unsigned int winFlags;	/* Various flag values:  these are all
				 * defined in tk.h (confusing, but they're
				 * needed there for some query macros). */

    struct {
	TkEventHandler *dummy1;	/* handlerList */
	void (*dummy7) ();	/* focusProc */
	ClientData dummy8;	/* focusData */
	unsigned long dummy9;	/* bindingMask */
    } unused;

    int optionLevel;		/* -1 means no option information is
				 * currently cached for this geometry manager.
				 * Otherwise this gives the level in
				 * the option stack at which info is
				 * cached. */

    /*
     * The rest differs from TkWindow 
     */

    struct TkGeomManager *childPtr;
    				/* First in list of child geometry structures,
				 * or NULL if no managed subwindows. 	*/
    struct TkGeomManager *parentPtr;
				/* Parent geometry manager structure */
    struct TkGeomManager *nextPtr;
				/* Next geometry manager shown within same
				 * parent. */
    int flags;			/* Miscellaneous flags.  See below. */
    void (*arrangeProc)();	/* Procedure to rearrange the children
				 * of this manager. */
    void (*destroyProc)();	/* Procedure to clean up individual manager. */
    ClientData *clientData;	/* Pointer to geometry manager private
				 * information.  Passed to arrangeProc
				 * and destroyProc. */
} TkGeomManager;

/*
 * Flag values for geometry manager structures:
 * REQUESTED_REARRANGE:		1 means we have a pending call
 *				  to map and/or move underlying window.
 * REARRANGE_CHILDREN		1 means children are out of order
 *
 * Additional flags may be defined by individual geometry managers.
 */

#define REQUESTED_REARRANGE	1
#define REARRANGE_CHILDREN	2

/*
 * Externally visible internal functions
 */

TkGeomManager *	TkCreateGeomManager _ANSI_ARGS_ ((Tkcl_Interp *interp,
			Tk_Window tkwin, char *name, void (*arrangeProc)(),
			void (*destroyProc)(), ClientData clientData));
void		TkLinkGeomManager _ANSI_ARGS_ ((TkGeomManager *parentPtr,
			TkGeomManager *childPtr, TkGeomManager *prevPtr));
void		TkGeomManagerReqProc _ANSI_ARGS_ ((ClientData clientData,
			Tk_window tkwin));
void		TkUnlinkGeomManager _ANSI_ARGS_ ((TkGeomManager *geomPtr));

#endif _TK_GEOM_MANAGER




